% Example name: LockedSetGroupwiseStochastic
% Description: this script creates 1 sample (list) of 100 words from a subset of the MRC database that includes only nouns ('MRCNouns.txt')
% The 1 sample is matched on 4 dimensions ('KFfrequency', 'letters', 'syllables', and 'phonemes') to 100 pre-selected verbs of frequency < 50 from the MRC database
% This optimization uses the stochastic method of annealing

% Sets the random seed
setSeed(123);

% Creates a population from the noun subset of the MRC database file with the name 'myPopulation'
myPopulation = population('MRCNouns.txt','name','myPopulation','isHeader',true,'isFormatting',true);
dummyPopulation = population('fakePop.txt','name','dummyPopulation','isHeader',true,'isFormatting',true);

% Reads in a sample with 100 pre-selected verbs from the file 'lockedSet.txt'
mySample1 = sample(100,'name','mySample1','filename','lockedSet.txt','isHeader',true,'isFormatting',true);
mySample1.setPop(dummyPopulation);

% Specifies that every item in this sample is to remain unchanged during optimization
mySample1.lockAll();

% Creates a second sample with 100 words that can be saved with the name 'mySample2.txt'
mySample2 = sample(100,'name','mySample2','outFile','mySample2.txt');

% Links mySample2 to the population file from which its items will be drawn
mySample2.setPop(myPopulation);

% Creates an SOS optimization called 'mySOS'
mySOS = sos();

% Adds the two samples to the 'mySOS' instance of optimization
mySOS = mySOS.addSample(mySample1);
mySOS = mySOS.addSample(mySample2);

% Adds one desired constraint with the name 'myConstraint': match the two lists on 'KFfrequency'
myConstraint = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint', 'constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'KFfrequency', 'S2ColName', 'KFfrequency', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds one desired constraint with the name 'myConstraint2': match the two lists on 'letters'
myConstraint2 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint2','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'letters', 'S2ColName', 'letters', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds one desired constraint with the name 'myConstraint3': match the two lists on 'syllables'
myConstraint3 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint3','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'syllables', 'S2ColName', 'syllables', 'exponent', 2, 'paired', false, 'weight', 1);

% Adds one desired constraint with the name 'myConstraint4': match the two lists on 'phonemes'
myConstraint4 = mySOS.addConstraint('sosObj', mySOS, 'name','myConstraint4','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'phonemes', 'S2ColName', 'phonemes', 'exponent', 2, 'paired', false, 'weight', 1);

% Fills the two samples with randomly selected items from the population file
mySOS.initFillSamples();

% Standardizes the values of the dimension(s) of interest
mySOS.normalizeData();

% Creates an independent samples t-test to determine whether or not the lists are matched on 'KFfrequency', p-value > 0.5
mySOS.addttest('name','myTTest','type','independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'KFfrequency', 's2ColName', 'KFfrequency', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates an independent samples t-test to determine whether or not the lists are matched on 'letters', p-value > 0.5
mySOS.addttest('name','myTTest2','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'letters', 's2ColName', 'letters', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates an independent samples t-test to determine whether or not the lists are matched on 'syllables', p-value > 0.5
mySOS.addttest('name','myTTest3','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'syllables', 's2ColName', 'syllables', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates an independent samples t-test to determine whether or not the lists are matched on 'phonemes', p-value > 0.5
mySOS.addttest('name','myTTest4','type', 'independent', 'sample1', mySample1, 'sample2', mySample2, 's1ColName', 'phonemes', 's2ColName', 'phonemes', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Determines the type of optimization that will be performed; no specification defaults to "greedy"
mySOS.setAnnealSchedule('schedule','exp');

% Starts the SOS GUI
sos_gui();
